@@ -3,14 +3,14 @@ Copyright (c) 2022 Plugin Andrey (9keepa@gmail.com)
 Licensed under the MIT License
 """
 from dataclasses import dataclass
-from .server import Response, Server
+from .server import ExecuteResult, RemoteServer
 from typing import Any
 
 
 @dataclass
 class IArgs:
-    server:Server
-    response:Response
+    server:RemoteServer
+    response:ExecuteResult
     config:Any
 
 
